% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/classes.R
\name{rxclass_relationships}
\alias{rxclass_relationships}
\title{Summarize RxClass relationship types for drugs}
\usage{
rxclass_relationships(
  x,
  by = c("rxcui", "name"),
  rela_source = NULL,
  show_progress = interactive()
)
}
\arguments{
\item{x}{Character vector of RxCUIs or drug names.}

\item{by}{One of \code{"rxcui"} or \code{"name"}.}

\item{rela_source}{Optional RxClass relationship source filter.}

\item{show_progress}{Logical. Show a progress bar in interactive sessions.
Progress is shown only when at least 5 inputs are supplied.}
}
\value{
A tibble summarizing available relationship/class-type combinations.
}
\description{
\code{rxclass_relationships()} is a diagnostic helper that evaluates the type(s)
of relationship (rela) asserted in RxNorm MED-RT data and the number within
each relationship asserted. In some cases, \code{get_medrt()} or its various
convenience wrappers may return empty or shorter-than-expected tibbles
because some relationships expected by the user are not asserted in RxNorm
(for example, an MOA may not be asserted by MED-RT).
}
