% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/classes.R
\name{get_medrt}
\alias{get_medrt}
\title{Get MED-RT assertions for RxNorm drugs}
\usage{
get_medrt(
  x,
  by = c("rxcui", "name"),
  relas = NULL,
  class_types = NULL,
  keep_input = TRUE,
  show_progress = interactive()
)
}
\arguments{
\item{x}{Character vector of RxCUIs or drug names.}

\item{by}{One of \code{"rxcui"} or \code{"name"}.}

\item{relas}{Optional MED-RT relationship filter.}

\item{class_types}{Optional MED-RT class type filter.}

\item{keep_input}{Logical; if \code{TRUE}, includes the original input value.}

\item{show_progress}{Logical. Show a progress bar in interactive sessions.
Progress is shown only when at least 5 inputs are supplied.}
}
\value{
A tibble of MED-RT assertions.
}
\description{
\code{get_medrt()} is a convenience wrapper for \code{get_classes()} that returns
MED-RT assertions for RxNorm drugs. These include, for example, asserted
mechanisms of action, contraindications, physiologic effects (including
adverse side effects), etc.
}
